@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Unit ;
-$Config::Model::Backend::Systemd::Unit::VERSION = '0.231.2';
+$Config::Model::Backend::Systemd::Unit::VERSION = '0.231.3';
 use strict;
 use warnings;
 use 5.010;
@@ -26,6 +26,9 @@ sub read {
     my $self = shift ;
     my %args = @_ ;
 
+    # enable 2 styles of comments (gh #1)
+    $args{comment_delimiter} = "#;";
+
     # args are:
     # root       => './my_test',  # fake root directory, used for tests
     # config_dir => /etc/foo',    # absolute path
@@ -36,7 +39,7 @@ sub read {
 
     if ($self->node->instance->layered) {
         # avoid deep recursion in layered mode
-        return $self->SUPER::read(@_);
+        return $self->SUPER::read(%args);
     };
 
     my $dir = path($args{root}.$args{config_dir});
@@ -75,7 +78,7 @@ sub read {
         $logger->debug("reading unit $unit_type name $unit_name from ".$args{config_dir});
 
         # mouse super() does not work...
-        $self->SUPER::read(@_);
+        $self->SUPER::read(%args);
     }
 }
 
@@ -195,7 +198,7 @@ Config::Model::Backend::Systemd::Unit - R/W backend for systemd unit files
 
 =head1 VERSION
 
-version 0.231.2
+version 0.231.3
 
 =head1 SYNOPSIS
 
